export default {
    "index": 30,
    "lineNumber": 1,
    "column": 31,
    "message": "Cannot use keyword 'await' outside an async function"
};
